@@ -70,6 +70,7 @@ from neutron_lib.api.definitions import l3_flavors
 from neutron_lib.api.definitions import l3_multi_ext_gw
 from neutron_lib.api.definitions import l3_ndp_proxy
 from neutron_lib.api.definitions import l3_port_ip_change_not_allowed
+from neutron_lib.api.definitions import local_ip
 from neutron_lib.api.definitions import logging
 from neutron_lib.api.definitions import logging_resource
 from neutron_lib.api.definitions import metering
@@ -98,12 +99,17 @@ from neutron_lib.api.definitions import qos
 from neutron_lib.api.definitions import qos_bw_limit_direction
 from neutron_lib.api.definitions import qos_bw_minimum_ingress
 from neutron_lib.api.definitions import qos_default
+from neutron_lib.api.definitions import qos_fip
+from neutron_lib.api.definitions import qos_fip_network_policy
 from neutron_lib.api.definitions import qos_gateway_ip
 from neutron_lib.api.definitions import qos_port_network_policy
 from neutron_lib.api.definitions import qos_pps_minimum_rule
+from neutron_lib.api.definitions import qos_pps_minimum_rule_alias
 from neutron_lib.api.definitions import qos_pps_rule
 from neutron_lib.api.definitions import qos_rule_type_details
+from neutron_lib.api.definitions import qos_rule_type_filter
 from neutron_lib.api.definitions import qos_rules_alias
+from neutron_lib.api.definitions import quota_check_limit
 from neutron_lib.api.definitions import rbac_address_groups
 from neutron_lib.api.definitions import rbac_address_scope
 from neutron_lib.api.definitions import rbac_bgpvpn
@@ -117,6 +123,7 @@ from neutron_lib.api.definitions import routerservicetype
 from neutron_lib.api.definitions import security_groups_normalized_cidr
 from neutron_lib.api.definitions import security_groups_port_filtering
 from neutron_lib.api.definitions import security_groups_remote_address_group
+from neutron_lib.api.definitions import security_groups_shared_filtering
 from neutron_lib.api.definitions import segment
 from neutron_lib.api.definitions import segments_peer_subnet_host_routes
 from neutron_lib.api.definitions import servicetype
@@ -133,10 +140,12 @@ from neutron_lib.api.definitions import subnet_segmentid_writable
 from neutron_lib.api.definitions import subnet_service_types
 from neutron_lib.api.definitions import subnetpool
 from neutron_lib.api.definitions import subnetpool_prefix_ops
+from neutron_lib.api.definitions import taas
 from neutron_lib.api.definitions import tag_ports_during_bulk_creation
 from neutron_lib.api.definitions import trunk
 from neutron_lib.api.definitions import trunk_details
 from neutron_lib.api.definitions import uplink_status_propagation
+from neutron_lib.api.definitions import vlan_filter
 from neutron_lib.api.definitions import vlantransparent
 from neutron_lib.api.definitions import vpn
 from neutron_lib.api.definitions import vpn_endpoint_groups
@@ -204,6 +213,7 @@ _ALL_API_DEFINITIONS = {
     l3_multi_ext_gw,
     l3_ndp_proxy,
     l3_port_ip_change_not_allowed,
+    local_ip,
     logging,
     logging_resource,
     metering,
@@ -232,12 +242,17 @@ _ALL_API_DEFINITIONS = {
     qos_bw_limit_direction,
     qos_bw_minimum_ingress,
     qos_default,
+    qos_fip,
+    qos_fip_network_policy,
     qos_gateway_ip,
     qos_port_network_policy,
     qos_pps_minimum_rule,
+    qos_pps_minimum_rule_alias,
     qos_pps_rule,
     qos_rule_type_details,
+    qos_rule_type_filter,
     qos_rules_alias,
+    quota_check_limit,
     rbac_address_groups,
     rbac_address_scope,
     rbac_bgpvpn,
@@ -251,6 +266,7 @@ _ALL_API_DEFINITIONS = {
     security_groups_normalized_cidr,
     security_groups_port_filtering,
     security_groups_remote_address_group,
+    security_groups_shared_filtering,
     segment,
     segments_peer_subnet_host_routes,
     servicetype,
@@ -267,10 +283,12 @@ _ALL_API_DEFINITIONS = {
     subnet_service_types,
     subnetpool,
     subnetpool_prefix_ops,
+    taas,
     tag_ports_during_bulk_creation,
     trunk,
     trunk_details,
     uplink_status_propagation,
+    vlan_filter,
     vlantransparent,
     vpn,
     vpn_endpoint_groups,
