@@ -141,10 +141,16 @@ KNOWN_EXTENSIONS = (
     'provider',
     'qos',
     'qos-bw-limit-direction',
+    'qos-fip',
+    'qos-fip-network-policy',
     'qos-gateway-ip',
     'qos-port-network-policy',
+    'qos-pps-minimum',
+    'qos-pps-minimum-rule-alias',
+    'qos-rule-type-filter',
     'qos-rules-alias',
     'quotas',
+    'quota-check-limit',
     'rbac-address-group',
     'rbac-address-scope',
     'rbac-bgpvpn',
@@ -191,6 +197,10 @@ KNOWN_EXTENSIONS = (
     # https://opendev.org/openstack/networking-sfc:
     'flow_classifier',
     'sfc',
+
+    # https://opendev.org/openstack/tap-as-a-service
+    'taas',
+    'taas-vlan-filter',
 )
 
 KNOWN_KEYWORDS = (
