@@ -94,6 +94,7 @@ RESOURCE_ATTRIBUTE_MAP = {
             'allow_put': True,
             'is_visible': True,
             'default': None,
+            'enforce_policy': True,
             'validate': {'type:uuid_or_none': None}
         }
     },
@@ -103,6 +104,7 @@ RESOURCE_ATTRIBUTE_MAP = {
             'allow_put': True,
             'is_visible': True,
             'default': None,
+            'enforce_policy': True,
             'validate': {'type:uuid_or_none': None}
         }
     }
@@ -116,7 +118,7 @@ SUB_RESOURCE_ATTRIBUTE_MAP = {
         'parent': _PARENT,
         'parameters': dict(
             _QOS_RULE_COMMON_FIELDS,
-            **{'max_kbps': {
+            **{qos_const.MAX_KBPS: {
                 'allow_post': True, 'allow_put': True,
                 'convert_to': converters.convert_to_int,
                 'is_visible': True,
@@ -125,7 +127,7 @@ SUB_RESOURCE_ATTRIBUTE_MAP = {
                 'validate': {
                     'type:range': [0, db_const.DB_INTEGER_MAX_VALUE]}
             },
-                'max_burst_kbps': {
+                qos_const.MAX_BURST: {
                     'allow_post': True, 'allow_put': True,
                     'is_visible': True, 'default': 0,
                     'is_filter': True,
@@ -138,7 +140,7 @@ SUB_RESOURCE_ATTRIBUTE_MAP = {
         'parent': _PARENT,
         'parameters': dict(
             _QOS_RULE_COMMON_FIELDS,
-            **{'dscp_mark': {
+            **{qos_const.DSCP_MARK: {
                 'allow_post': True, 'allow_put': True,
                 'convert_to': converters.convert_to_int,
                 'is_visible': True,
@@ -151,7 +153,7 @@ SUB_RESOURCE_ATTRIBUTE_MAP = {
         'parent': _PARENT,
         'parameters': dict(
             _QOS_RULE_COMMON_FIELDS,
-            **{'min_kbps': {
+            **{qos_const.MIN_KBPS: {
                 'allow_post': True, 'allow_put': True,
                 'is_visible': True,
                 'is_filter': True,
@@ -159,7 +161,7 @@ SUB_RESOURCE_ATTRIBUTE_MAP = {
                 'convert_to': converters.convert_to_int,
                 'validate': {
                     'type:range': [0, db_const.DB_INTEGER_MAX_VALUE]}},
-                'direction': {
+                qos_const.DIRECTION: {
                     'allow_post': True, 'allow_put': True,
                     'is_visible': True, 'default': constants.EGRESS_DIRECTION,
                     'is_filter': True,
