@@ -96,3 +96,8 @@ class IpTablesApplyException(exceptions.NeutronException):
     def __init__(self, message=None):
         self.message = message
         super().__init__()
+
+
+class BfdMonitorInUse(exceptions.InUse):
+    message = _("Unable to complete operation on BFD monitor %(bfd_id)s. "
+                "There are one or more routes that still use the monitor.")
