@@ -26,6 +26,7 @@ from neutron_lib._i18n import _
 from neutron_lib.api import attributes
 from neutron_lib.api.definitions import network as net_apidef
 from neutron_lib.api.definitions import port as port_apidef
+from neutron_lib.api.definitions import portbindings as pb
 from neutron_lib.api.definitions import portbindings_extended as pb_ext
 from neutron_lib.api.definitions import subnet as subnet_apidef
 from neutron_lib import constants
@@ -198,9 +199,11 @@ def parse_network_vlan_ranges(network_vlan_ranges_cfg_entries):
     for entry in network_vlan_ranges_cfg_entries:
         network, vlan_range = parse_network_vlan_range(entry)
         if vlan_range:
+            if networks.get(network) == [constants.VLAN_VALID_RANGE]:
+                continue
             networks.setdefault(network, []).append(vlan_range)
         else:
-            networks.setdefault(network, [])
+            networks[network] = [constants.VLAN_VALID_RANGE]
     return networks
 
 
@@ -305,7 +308,7 @@ def _fixup_res_dict(context, attr_name, res_dict, check_allow_post=True):
     except web_exc.HTTPBadRequest as e:
         # convert webob exception into ValueError as these functions are
         # for internal use. webob exception doesn't make sense.
-        raise ValueError(e.detail)
+        raise ValueError(e.detail) from e
     attr_ops.fill_post_defaults(res_dict, check_allow_post=check_allow_post)
     attr_ops.convert_values(res_dict)
     return res_dict
@@ -382,3 +385,12 @@ def get_port_binding_by_status_and_host(bindings, status, host='',
                 return binding
     if raise_if_not_found:
         raise exceptions.PortBindingNotFound(port_id=port_id, host=host)
+
+
+def can_port_be_bound_to_virtual_bridge(port):
+    """Returns if port can be bound to a virtual bridge (e.g.: LB, OVS)
+
+    :param port: (dict) A port dictionary.
+    :returns: True if the port VNIC type is 'normal'; False in any other case.
+    """
+    return port[pb.VNIC_TYPE] == pb.VNIC_NORMAL
