@@ -222,6 +222,59 @@ class TestAttributeValidation(base.BaseTestCase):
         msg = validators.validate_list_of_unique_strings(data, None)
         self.assertIsNone(msg)
 
+    def test_validate_oneline_not_empty_string(self):
+        data = "Test"
+        msg = validators.validate_oneline_not_empty_string(data, None)
+        self.assertIsNone(msg)
+
+        data = "Test but this is too long"
+        max_len = 4
+        msg = validators.validate_oneline_not_empty_string(data, max_len)
+        self.assertEqual(
+            "'%s' exceeds maximum length of %s" % (data, max_len),
+            msg)
+
+        data = "First line\nsecond line"
+        msg = validators.validate_oneline_not_empty_string(data, None)
+        self.assertEqual(
+            "Multi-line string is not allowed: '%s'" % data,
+            msg)
+
+        data = ""
+        msg = validators.validate_oneline_not_empty_string(data, None)
+        self.assertEqual(
+            "'%s' Blank strings are not permitted" % data,
+            msg)
+
+    def test_validate_oneline_not_empty_string_or_none(self):
+        data = "Test"
+        msg = validators.validate_oneline_not_empty_string_or_none(data, None)
+        self.assertIsNone(msg)
+
+        data = None
+        msg = validators.validate_oneline_not_empty_string_or_none(data, None)
+        self.assertIsNone(msg)
+
+        data = "Test but this is too long"
+        max_len = 4
+        msg = validators.validate_oneline_not_empty_string_or_none(
+            data, max_len)
+        self.assertEqual(
+            "'%s' exceeds maximum length of %s" % (data, max_len),
+            msg)
+
+        data = "First line\nsecond line"
+        msg = validators.validate_oneline_not_empty_string_or_none(data, None)
+        self.assertEqual(
+            "Multi-line string is not allowed: '%s'" % data,
+            msg)
+
+        data = ""
+        msg = validators.validate_oneline_not_empty_string(data, None)
+        self.assertEqual(
+            "'%s' Blank strings are not permitted" % data,
+            msg)
+
     def test_validate_boolean(self):
         msg = validators.validate_boolean(True)
         self.assertIsNone(msg)
@@ -542,6 +595,14 @@ class TestAttributeValidation(base.BaseTestCase):
                              'destination': '100.0.0.0/8'},
                             {'nexthop': '10.0.2.20',
                              'destination': '100.0.0.0/8'}],
+                           [{'nexthop': '10.0.2.20',
+                             'destination': '101.0.0.0/8',
+                             'bfd_monitor_id':
+                                 'uuid'}],
+                           [{'nexthop': '10.0.2.20',
+                             'destination': '101.0.0.0/8',
+                             'bfd_monitor_id':
+                                 None}],
                            [None],
                            None]
         for host_routes in hostroute_pools:
@@ -553,7 +614,20 @@ class TestAttributeValidation(base.BaseTestCase):
                            [{'nexthop': '10.0.2.20',
                              'destination': '100.0.0.0/8'},
                             {'nexthop': '10.0.2.20',
-                             'destination': '101.0.0.0/8'}]]
+                             'destination': '101.0.0.0/8'}],
+                           [{'nexthop': '10.0.2.20',
+                             'destination': '100.0.0.0/24'},
+                            {'nexthop': '10.0.2.20',
+                             'destination': '101.0.0.0/8',
+                             'bfd_monitor_id':
+                                 '469e4b94-f607-11eb-a9a2-038e2b6c9f81'}],
+                           [{'nexthop': '10.0.2.20',
+                             'destination': '101.0.0.0/8',
+                             'bfd_monitor_id':
+                                 '469e4b94-f607-11eb-a9a2-038e2b6c9f81'},
+                            {'nexthop': '10.0.2.20',
+                             'destination': '100.0.0.0/24'}]
+                           ]
         for host_routes in hostroute_pools:
             msg = validators.validate_hostroutes(host_routes, None)
             self.assertIsNone(msg)
@@ -897,6 +971,24 @@ class TestAttributeValidation(base.BaseTestCase):
         msg = validators._validate_list_of_items_non_empty(mock.Mock(), items)
         self.assertEqual("List should not be empty", msg)
 
+    def test__validate_list_of_items_collect_duplicates(self):
+        items = ['a', 'b', 'duplicate_1', 'duplicate_2', 'duplicate_1',
+                 'duplicate_2', 'duplicate_2', 'c']
+        msg = validators._validate_list_of_items(mock.Mock(), items)
+        error = ("Duplicate items in the list: '%s'"
+                 % 'duplicate_1, duplicate_2')
+        self.assertEqual(error, msg)
+
+        items = [['a', 'b'], ['c', 'd'], ['a', 'b']]
+        msg = validators._validate_list_of_items(mock.Mock(), items)
+        error = "Duplicate items in the list: '%s'" % ['a', 'b']
+        self.assertEqual(error, msg)
+
+        items = [{'a': 'b'}, {'c': 'd'}, {'a': 'b'}]
+        msg = validators._validate_list_of_items(mock.Mock(), items)
+        error = "Duplicate items in the list: '%s'" % {'a': 'b'}
+        self.assertEqual(error, msg)
+
     def test_validate_dict_type(self):
         for value in (None, True, '1', []):
             self.assertEqual("'%s' is not a dictionary" % value,
