@@ -12,6 +12,7 @@
 
 from unittest import mock
 
+from oslo_config import cfg
 from oslo_context import context as oslo_context
 from testtools import matchers
 
@@ -36,8 +37,6 @@ class TestNeutronContext(_base.BaseTestCase):
         if isinstance(request_id, bytes):
             request_id = request_id.decode('utf-8')
         self.assertThat(request_id, matchers.StartsWith('req-'))
-        self.assertEqual('user_id', ctx.user)
-        self.assertEqual('tenant_id', ctx.tenant)
         self.assertIsNone(ctx.user_name)
         self.assertIsNone(ctx.tenant_name)
         self.assertIsNone(ctx.project_name)
@@ -60,8 +59,8 @@ class TestNeutronContext(_base.BaseTestCase):
         self.assertEqual('tenant_name', ctx.tenant_name)
         self.assertEqual('tenant_name', ctx.project_name)
         # Check user/tenant contains its ID even if user/tenant_name is passed
-        self.assertEqual('user_id', ctx.user)
-        self.assertEqual('tenant_id', ctx.tenant)
+        self.assertEqual('user_id', ctx.user_id)
+        self.assertEqual('tenant_id', ctx.tenant_id)
 
     def test_neutron_context_create_with_request_id(self):
         ctx = context.Context('user_id', 'tenant_id', request_id='req_id_xxx')
@@ -152,6 +151,16 @@ class TestNeutronContext(_base.BaseTestCase):
         elevated2_ctx = elevated_ctx.elevated()
         self.assertTrue(elevated2_ctx.is_admin)
 
+    def test_neutron_context_elevated_system_scope_for_new_policies(self):
+        cfg.CONF.set_override(
+            'enforce_new_defaults', True, group='oslo_policy')
+        ctx = context.Context('user_id', 'tenant_id')
+        self.assertFalse(ctx.is_admin)
+        self.assertNotEqual('all', ctx.system_scope)
+        elevated_ctx = ctx.elevated()
+        self.assertTrue(elevated_ctx.is_admin)
+        self.assertEqual('all', elevated_ctx.system_scope)
+
     def test_neutron_context_overwrite(self):
         ctx1 = context.Context('user_id', 'tenant_id')
         self.assertEqual(ctx1.request_id,
@@ -185,10 +194,9 @@ class TestNeutronContext(_base.BaseTestCase):
             'is_admin': 'is_admin',
             'tenant_name': 'tenant_name',
             'user_name': 'user_name',
-            'domain': 'domain',
-            'user_domain': 'user_domain',
-            'project_domain': 'project_domain',
-            'user_name': 'user_name',
+            'domain_id': 'domain',
+            'user_domain_id': 'user_domain',
+            'project_domain_id': 'project_domain',
         }
         additional_values = {
             'user': 'user_id',
@@ -203,12 +211,6 @@ class TestNeutronContext(_base.BaseTestCase):
         self.assertDictSupersetOf(values, policy_values)
         self.assertDictSupersetOf(additional_values, policy_values)
 
-    @mock.patch.object(context.ContextBaseWithSession, 'session')
-    def test_superclass_session(self, mocked_session):
-        ctx = context.Context('user_id', 'tenant_id')
-        # make sure context uses parent class session that is mocked
-        self.assertEqual(mocked_session, ctx.session)
-
     def test_session_cached(self):
         ctx = context.Context('user_id', 'tenant_id')
         session1 = ctx.session
